==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/enums/KnownSyslogDataSourceLogLevels.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class KnownSyslogDataSourceLogLevels(
    public val javaValue: com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels,
) : ConvertibleToJava<com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels> {
    Debug(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Debug),
    Info(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Info),
    Notice(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Notice),
    Warning(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Warning),
    Error(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Error),
    Critical(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Critical),
    Alert(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Alert),
    Emergency(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Emergency),
    Asterisk(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Asterisk),
    ;

    override fun toJava(): com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels):
            KnownSyslogDataSourceLogLevels =
            KnownSyslogDataSourceLogLevels.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/insights/kotlin/enums/KnownSyslogDataSourceLogLevels.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class KnownSyslogDataSourceLogLevels(
    public val javaValue: com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels,
) : ConvertibleToJava<com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels> {
    Debug(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Debug),
    Info(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Info),
    Notice(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Notice),
    Warning(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Warning),
    Error(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Error),
    Critical(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Critical),
    Alert(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Alert),
    Emergency(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Emergency),
    Asterisk(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels.Asterisk),
    ;

    override fun toJava(): com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceLogLevels): KnownSyslogDataSourceLogLevels =
            KnownSyslogDataSourceLogLevels.values().first { it.javaValue == javaType }
    }
}
